@@ -3,7 +3,7 @@ package
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 use Config;
 use Path::Class qw( file dir );
 
